@@ -6,8 +6,12 @@ from dotenv import find_dotenv, load_dotenv
 from openai import OpenAI
 from pinecone import Pinecone, ServerlessSpec
 
-from langtrace_python_sdk import langtrace, with_langtrace_root_span
-from langtrace_python_sdk.utils.with_root_span import send_user_feedback
+from langtrace_python_sdk import (
+    langtrace,
+    with_langtrace_root_span,
+    with_additional_attributes,
+)
+from langtrace_python_sdk.utils.with_root_span import SendUserFeedback
 
 _ = load_dotenv(find_dotenv())
 
@@ -28,8 +32,9 @@ def create_index():
     )
 
 
-@with_langtrace_root_span()
-def basic(span_id, trace_id):
+@with_additional_attributes({"db.embedding_model": "text-embedding-ada-002"})
+@with_langtrace_root_span("Pinecone Basic")
+def basic(span_id=None, trace_id=None):
 
     result = client.embeddings.create(
         model="text-embedding-ada-002",
@@ -44,16 +49,14 @@ def basic(span_id, trace_id):
 
     index = pinecone.Index(PINECONE_INDEX_NAME)
     res = index.upsert(vectors=[data_to_upsert], namespace="test-namespace")
-    print("res", res)
 
     resp = index.query(
         vector=embedding, top_k=1, include_values=False, namespace="test-namespace"
     )
-    send_user_feedback(
+    SendUserFeedback().evaluate(
         {"spanId": span_id, "traceId": trace_id, "userScore": 1, "userId": "123"}
     )
-    print(resp)
+    return [res, resp]
 
 
 # create_index()
-basic("span_id", "trace_id")
